@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.16.2";
+our $VERSION = "v0.17.0";
 
 1;
 __END__
@@ -166,11 +166,20 @@ L<https://rxjs.dev/api/index/const/EMPTY>
         rx_of(40, 50, 60),
     )->subscribe($subscriber);
 
+=item rx_from
+
+L<https://rxjs.dev/api/index/function/from>
+
+Currently, only arrayrefs, promises, and observables are allowed as argument to this function.
+
+    # 10, 20, 30, complete
+    rx_from([10, 20, 30])->subscribe($subscriber);
+
 =item rx_from_event
 
 L<https://rxjs.dev/api/index/function/fromEvent>
 
-Currently, only instances of the L<Mojo::EventEmitter> class are allowed as the first argument of this function.
+Currently, only instances of the L<Mojo::EventEmitter> class are allowed as the first argument to this function.
 
     # 4 seconds after Mojolicious hypnotoad is gracefully reloaded, websocket
     # connection will close
